@@ -92,7 +92,6 @@ namespace GeographicLib {
   }
 
   AuxAngle AuxLatitude::Rectifying(const AuxAngle& phi, real* diff) const {
-    using std::isinf;           // Needed for Centos 7, ubuntu 14
     AuxAngle beta(Parametric(phi).normalized());
     real sbeta = fabs(beta.y()), cbeta = fabs(beta.x());
     real a = 1, b = _fm1, ka = _e2, kb = -_e12, ka1 = _e2m1, kb1 = _e12p1,
@@ -138,7 +137,6 @@ namespace GeographicLib {
   }
 
   AuxAngle AuxLatitude::Conformal(const AuxAngle& phi, real* diff) const {
-    using std::isinf;           // Needed for Centos 7, ubuntu 14
     real tphi = fabs(phi.tan()), tchi = tphi;
     if ( !( !isfinite(tphi) || tphi == 0 || _f == 0 ) ) {
       real scphi = sc(tphi),
@@ -196,7 +194,6 @@ namespace GeographicLib {
   }
 
   AuxAngle AuxLatitude::Authalic(const AuxAngle& phi, real* diff) const {
-    using std::isnan;           // Needed for Centos 7, ubuntu 14
     real tphi = fabs(phi.tan());
     AuxAngle xi(phi), phin(phi.normalized());
     if ( !( !isfinite(tphi) || tphi == 0 || _f == 0 ) ) {
@@ -296,7 +293,6 @@ namespace GeographicLib {
 
   AuxAngle AuxLatitude::Convert(int auxin, int auxout, const AuxAngle& zeta,
                                 bool exact) const {
-    using std::isnan;           // Needed for Centos 7, ubuntu 14
     int k = ind(auxout, auxin);
     if (k < 0) return AuxAngle::NaN();
     if (auxin == auxout) return zeta;
