@@ -37,11 +37,6 @@
 #include <complex>
 #include <GeographicLib/TransverseMercator.hpp>
 
-#if defined(_MSC_VER)
-// Squelch warnings about enum-float expressions
-#  pragma warning (disable: 5055)
-#endif
-
 namespace GeographicLib {
 
   using namespace std;
